<?php
  /**************************************************************************\
  * eGroupWare - Polls                                                       *
  * http://www.egroupware.org                                                *
  * Copyright (c) 1999 Till Gerken (tig@skv.org)                             *
  * Modified by Greg Haygood (shrykedude@bellsouth.net)                      *
  * -----------------------------------------------                          *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */

	$GLOBALS['egw_info'] = array(
		'flags' => array(
			'currentapp'              => 'polls',
			'noheader'                => True,
			'nonavbar'                => True,
			'enable_nextmatchs_class' => True,
		),
	);
	include('../header.inc.php');

	ExecMethod('polls.ui.index');

	$GLOBALS['egw']->common->egw_footer();
?>
